@@ -1,12 +1,22 @@
+package CPAN::YACSmoke::Plugin::WebList;
+
+use 5.006001;
+use strict;
+use warnings;
+
+our $VERSION = '0.03';
+
+# -------------------------------------
+
 =head1 NAME
 
-CPAN::YACSmoke::Plugin::WebList - WebList list for Yet Another CPAN Smoke Tester
+CPAN::YACSmoke::Plugin::WebList - WebList plugin for CPAN::YACSmoke
 
 =head1 SYNOPSIS
 
   use CPAN::YACSmoke;
   my $config = {
-	  list_from => 'WebList', 
+      list_from => 'WebList', 
       webpath => 'http://my.web.list/' # defaults to KobeSearch site
   };
   my $foo = CPAN::YACSmoke->new(config => $config);
@@ -38,14 +48,6 @@ added in the future.
 
 =cut
 
-package CPAN::YACSmoke::Plugin::WebList;
-
-use 5.006001;
-use strict;
-use warnings;
-
-our $VERSION = '0.02';
-
 # -------------------------------------
 # Library Modules
 
@@ -130,8 +132,6 @@ sub download_list {
 1;
 __END__
 
-=pod
-
 =back
 
 =head1 CAVEATS
@@ -148,10 +148,16 @@ severely buggy.  Do not run this on a critical machine.
 This module uses the backend of CPANPLUS to do most of the work, so is
 subject to any bugs of CPANPLUS.
 
-=head2 Suggestions and Bug Reporting
+=head1 BUGS, PATCHES & FIXES
 
-Please submit suggestions and report bugs to the CPAN Bug Tracker at
-L<http://rt.cpan.org>.
+There are no known bugs at the time of this release. However, if you spot a
+bug or are experiencing difficulties, that is not explained within the POD
+documentation, please send an email to barbie@cpan.org or submit a bug to the
+RT system (http://rt.cpan.org/). However, it would help greatly if you are 
+able to pinpoint problems or even supply a patch. 
+
+Fixes are dependant upon their severity and my availablity. Should a fix not
+be forthcoming, please feel free to (politely) remind me.
 
 =head1 SEE ALSO
 
@@ -166,14 +172,12 @@ For additional information, see the documentation for these modules:
 
 =head1 AUTHOR
 
-Barbie, C< <<barbie@cpan.org>> >
-for Miss Barbell Productions, L<http://www.missbarbell.co.uk>
-
-Birmingham Perl Mongers, L<http://birmingham.pm.org/>
+  Barbie, <barbie@cpan.org>
+  for Miss Barbell Productions <http://www.missbarbell.co.uk>.
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2005 Barbie for Miss Barbell Productions
+  Copyright (C) 2005 Barbie for Miss Barbell Productions.
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or 
